@@ -13,7 +13,7 @@
 
 from ..core.abstractcontroller import AbstractBaseController
 from ..resources.strings import strings
-from ..core import fileoperations, operations, io
+from ..operations import consoleops
 
 
 class ConsoleController(AbstractBaseController):
@@ -24,7 +24,6 @@ class ConsoleController(AbstractBaseController):
 
     def do_command(self):
         app_name = self.get_app_name()
-        region = self.get_region()
         env_name = self.get_env_name(noerror=True)
 
-        operations.open_console(app_name, env_name, region)
\ No newline at end of file
+        consoleops.open_console(app_name, env_name)
\ No newline at end of file
