@@ -13,7 +13,7 @@
 
 from ..core.abstractcontroller import AbstractBaseController
 from ..resources.strings import strings
-from ..core import operations
+from ..operations import envvarops
 
 
 class PrintEnvController(AbstractBaseController):
@@ -24,7 +24,6 @@ class PrintEnvController(AbstractBaseController):
 
     def do_command(self):
         app_name = self.get_app_name()
-        region = self.get_region()
         env_name = self.get_env_name()
 
-        operations.print_environment_vars(app_name, env_name, region)
\ No newline at end of file
+        envvarops.get_and_print_environment_vars(app_name, env_name)
