@@ -11,9 +11,10 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
+
 from ..core.abstractcontroller import AbstractBaseController
 from ..resources.strings import strings
-from ..core import operations
+from ..operations import statusops, commonops
 
 
 class StatusController(AbstractBaseController):
@@ -24,8 +25,8 @@ class StatusController(AbstractBaseController):
 
     def do_command(self):
         app_name = self.get_app_name()
-        region = self.get_region()
         env_name = self.get_env_name()
+
         verbose = self.app.pargs.verbose
 
-        operations.status(app_name, env_name, region, verbose)
\ No newline at end of file
+        statusops.status(app_name, env_name, verbose)
\ No newline at end of file
