@@ -16,6 +16,7 @@ from cement.utils.misc import minimal_logger
 from ..lib import aws
 from ..objects.exceptions import ServiceError, NotFoundError
 from ..resources.strings import responses
+from ..resources.statics import elb_names
 
 LOG = minimal_logger(__name__)
 
@@ -23,13 +24,16 @@ LOG = minimal_logger(__name__)
 def _make_api_call(operation_name, **operation_options):
     return aws.make_api_call('elb', operation_name, **operation_options)
 
+def version(load_balancer_name):
+    if '/app/' in load_balancer_name:
+        return elb_names.APPLICATION_VERSION
+    return elb_names.CLASSIC_VERSION
 
-def get_health_of_instances(load_balancer_name, region=None):
+def get_health_of_instances(load_balancer_name):
     try:
-        result = _make_api_call('describe-instance-health',
-                            load_balancer_name=load_balancer_name,
-                            region=region)
+        result = _make_api_call('describe_instance_health',
+                            LoadBalancerName=load_balancer_name)
     except ServiceError as e:
         if e.message.startswith(responses['loadbalancer.notfound']):
             raise NotFoundError(e)
-    return result['InstanceStates']
\ No newline at end of file
+    return result['InstanceStates']
