@@ -12,12 +12,13 @@
 # language governing permissions and limitations under the License.
 
 
-class Environment():
+class Environment(object):
     def __init__(self, version_label=None, status=None, app_name=None,
                  health=None, id=None, date_updated=None,
                  platform=None, description=None,
                  name=None, date_created=None, tier=None,
-                 cname=None):
+                 cname=None, option_settings=None, is_abortable=False,
+                 environment_links=None):
 
         self.version_label = version_label
         self.status = status
@@ -31,6 +32,9 @@ class Environment():
         self.date_created = date_created
         self.tier = tier
         self.cname = cname
+        self.option_settings = option_settings
+        self.is_abortable = is_abortable
+        self.environment_links = environment_links
 
     def __str__(self):
         return self.name
\ No newline at end of file
