@@ -19,10 +19,16 @@ def get_all_regions():
         Region('us-west-2', 'US West (Oregon)'),
         Region('eu-west-1', 'EU (Ireland)'),
         Region('eu-central-1', 'EU (Frankfurt)'),
+        Region('ap-south-1', 'Asia Pacific (Mumbai)'),
         Region('ap-southeast-1', 'Asia Pacific (Singapore)'),
         Region('ap-southeast-2', 'Asia Pacific (Sydney)'),
         Region('ap-northeast-1', 'Asia Pacific (Tokyo)'),
+        Region('ap-northeast-2', 'Asia Pacific (Seoul)'),
         Region('sa-east-1', 'South America (Sao Paulo)'),
+        Region('cn-north-1', 'China (Beijing)'),
+        Region('us-east-2', 'US East (Ohio)'),
+        Region('ca-central-1', 'Canada (Central)'),
+        Region('eu-west-2', 'EU (London)'),
     ]
 
 
@@ -32,4 +38,4 @@ class Region():
         self.description = description
 
     def __str__(self):
-        return self.name + ' : ' + self.description
\ No newline at end of file
+        return self.name + ' : ' + self.description
